rpcpb

package
v0.0.0-...-88ff46c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2018 License: AGPL-3.0 Imports: 13 Imported by: 0

Documentation

Overview

Package rpcpb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterApiServiceHandler

func RegisterApiServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterApiServiceHandler registers the http handlers for service ApiService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterApiServiceHandlerClient

func RegisterApiServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client ApiServiceClient) error

RegisterApiServiceHandler registers the http handlers for service ApiService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "ApiServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "ApiServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "ApiServiceClient" to call the correct interceptors.

func RegisterApiServiceHandlerFromEndpoint

func RegisterApiServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterApiServiceHandlerFromEndpoint is same as RegisterApiServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterApiServiceServer

func RegisterApiServiceServer(s *grpc.Server, srv ApiServiceServer)

Types

type ApiServiceClient

type ApiServiceClient interface {
	// state
	GetState(ctx context.Context, in *NonParamsRequest, opts ...grpc.CallOption) (*GetStateResponse, error)
	ListAssets(ctx context.Context, in *ListAssetsRequest, opts ...grpc.CallOption) (*ListAssetsResponse, error)
	ListTransactions(ctx context.Context, in *ListTransactionsRequest, opts ...grpc.CallOption) (*ListTransactionsResponse, error)
	SubmitTransaction(ctx context.Context, in *SubmitTransactionRequest, opts ...grpc.CallOption) (*SubmitTransactionResponse, error)
	EstimateTransactionGas(ctx context.Context, in *EstimateTransactionGasRequest, opts ...grpc.CallOption) (*EstimateTransactionGasResponse, error)
}

ApiServiceClient is the client API for ApiService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewApiServiceClient

func NewApiServiceClient(cc *grpc.ClientConn) ApiServiceClient

type ApiServiceServer

ApiServiceServer is the server API for ApiService service.

type Asset

type Asset struct {
	AssetID              string   `protobuf:"bytes,1,opt,name=assetID" json:"assetID,omitempty"`
	Amount               uint64   `protobuf:"varint,2,opt,name=amount" json:"amount,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Asset) Descriptor

func (*Asset) Descriptor() ([]byte, []int)

func (*Asset) GetAmount

func (m *Asset) GetAmount() uint64

func (*Asset) GetAssetID

func (m *Asset) GetAssetID() string

func (*Asset) ProtoMessage

func (*Asset) ProtoMessage()

func (*Asset) Reset

func (m *Asset) Reset()

func (*Asset) String

func (m *Asset) String() string

func (*Asset) XXX_DiscardUnknown

func (m *Asset) XXX_DiscardUnknown()

func (*Asset) XXX_Marshal

func (m *Asset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Asset) XXX_Merge

func (dst *Asset) XXX_Merge(src proto.Message)

func (*Asset) XXX_Size

func (m *Asset) XXX_Size() int

func (*Asset) XXX_Unmarshal

func (m *Asset) XXX_Unmarshal(b []byte) error

type EstimateTransactionGasRequest

type EstimateTransactionGasRequest struct {
	TransactionTemplate  string   `protobuf:"bytes,1,opt,name=transactionTemplate" json:"transactionTemplate,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

gas

func (*EstimateTransactionGasRequest) Descriptor

func (*EstimateTransactionGasRequest) Descriptor() ([]byte, []int)

func (*EstimateTransactionGasRequest) GetTransactionTemplate

func (m *EstimateTransactionGasRequest) GetTransactionTemplate() string

func (*EstimateTransactionGasRequest) ProtoMessage

func (*EstimateTransactionGasRequest) ProtoMessage()

func (*EstimateTransactionGasRequest) Reset

func (m *EstimateTransactionGasRequest) Reset()

func (*EstimateTransactionGasRequest) String

func (*EstimateTransactionGasRequest) XXX_DiscardUnknown

func (m *EstimateTransactionGasRequest) XXX_DiscardUnknown()

func (*EstimateTransactionGasRequest) XXX_Marshal

func (m *EstimateTransactionGasRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*EstimateTransactionGasRequest) XXX_Merge

func (dst *EstimateTransactionGasRequest) XXX_Merge(src proto.Message)

func (*EstimateTransactionGasRequest) XXX_Size

func (m *EstimateTransactionGasRequest) XXX_Size() int

func (*EstimateTransactionGasRequest) XXX_Unmarshal

func (m *EstimateTransactionGasRequest) XXX_Unmarshal(b []byte) error

type EstimateTransactionGasResponse

type EstimateTransactionGasResponse struct {
	TotalNeu             int64    `protobuf:"varint,1,opt,name=totalNeu" json:"totalNeu,omitempty"`
	StorageNeu           int64    `protobuf:"varint,2,opt,name=storageNeu" json:"storageNeu,omitempty"`
	VmNeu                int64    `protobuf:"varint,3,opt,name=vmNeu" json:"vmNeu,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*EstimateTransactionGasResponse) Descriptor

func (*EstimateTransactionGasResponse) Descriptor() ([]byte, []int)

func (*EstimateTransactionGasResponse) GetStorageNeu

func (m *EstimateTransactionGasResponse) GetStorageNeu() int64

func (*EstimateTransactionGasResponse) GetTotalNeu

func (m *EstimateTransactionGasResponse) GetTotalNeu() int64

func (*EstimateTransactionGasResponse) GetVmNeu

func (m *EstimateTransactionGasResponse) GetVmNeu() int64

func (*EstimateTransactionGasResponse) ProtoMessage

func (*EstimateTransactionGasResponse) ProtoMessage()

func (*EstimateTransactionGasResponse) Reset

func (m *EstimateTransactionGasResponse) Reset()

func (*EstimateTransactionGasResponse) String

func (*EstimateTransactionGasResponse) XXX_DiscardUnknown

func (m *EstimateTransactionGasResponse) XXX_DiscardUnknown()

func (*EstimateTransactionGasResponse) XXX_Marshal

func (m *EstimateTransactionGasResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*EstimateTransactionGasResponse) XXX_Merge

func (dst *EstimateTransactionGasResponse) XXX_Merge(src proto.Message)

func (*EstimateTransactionGasResponse) XXX_Size

func (m *EstimateTransactionGasResponse) XXX_Size() int

func (*EstimateTransactionGasResponse) XXX_Unmarshal

func (m *EstimateTransactionGasResponse) XXX_Unmarshal(b []byte) error

type GetStateResponse

type GetStateResponse struct {
	Status               string   `protobuf:"bytes,1,opt,name=status" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetStateResponse) Descriptor

func (*GetStateResponse) Descriptor() ([]byte, []int)

func (*GetStateResponse) GetStatus

func (m *GetStateResponse) GetStatus() string

func (*GetStateResponse) ProtoMessage

func (*GetStateResponse) ProtoMessage()

func (*GetStateResponse) Reset

func (m *GetStateResponse) Reset()

func (*GetStateResponse) String

func (m *GetStateResponse) String() string

func (*GetStateResponse) XXX_DiscardUnknown

func (m *GetStateResponse) XXX_DiscardUnknown()

func (*GetStateResponse) XXX_Marshal

func (m *GetStateResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetStateResponse) XXX_Merge

func (dst *GetStateResponse) XXX_Merge(src proto.Message)

func (*GetStateResponse) XXX_Size

func (m *GetStateResponse) XXX_Size() int

func (*GetStateResponse) XXX_Unmarshal

func (m *GetStateResponse) XXX_Unmarshal(b []byte) error

type Input

type Input struct {
	Type                 string   `protobuf:"bytes,1,opt,name=type" json:"type,omitempty"`
	AssetID              string   `protobuf:"bytes,2,opt,name=assetID" json:"assetID,omitempty"`
	Amount               uint64   `protobuf:"varint,3,opt,name=amount" json:"amount,omitempty"`
	Address              string   `protobuf:"bytes,4,opt,name=address" json:"address,omitempty"`
	SpentOutputID        string   `protobuf:"bytes,5,opt,name=spentOutputID" json:"spentOutputID,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

transactions

func (*Input) Descriptor

func (*Input) Descriptor() ([]byte, []int)

func (*Input) GetAddress

func (m *Input) GetAddress() string

func (*Input) GetAmount

func (m *Input) GetAmount() uint64

func (*Input) GetAssetID

func (m *Input) GetAssetID() string

func (*Input) GetSpentOutputID

func (m *Input) GetSpentOutputID() string

func (*Input) GetType

func (m *Input) GetType() string

func (*Input) ProtoMessage

func (*Input) ProtoMessage()

func (*Input) Reset

func (m *Input) Reset()

func (*Input) String

func (m *Input) String() string

func (*Input) XXX_DiscardUnknown

func (m *Input) XXX_DiscardUnknown()

func (*Input) XXX_Marshal

func (m *Input) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Input) XXX_Merge

func (dst *Input) XXX_Merge(src proto.Message)

func (*Input) XXX_Size

func (m *Input) XXX_Size() int

func (*Input) XXX_Unmarshal

func (m *Input) XXX_Unmarshal(b []byte) error

type ListAssetsRequest

type ListAssetsRequest struct {
	Address              string   `protobuf:"bytes,1,opt,name=address" json:"address,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

assets

func (*ListAssetsRequest) Descriptor

func (*ListAssetsRequest) Descriptor() ([]byte, []int)

func (*ListAssetsRequest) GetAddress

func (m *ListAssetsRequest) GetAddress() string

func (*ListAssetsRequest) ProtoMessage

func (*ListAssetsRequest) ProtoMessage()

func (*ListAssetsRequest) Reset

func (m *ListAssetsRequest) Reset()

func (*ListAssetsRequest) String

func (m *ListAssetsRequest) String() string

func (*ListAssetsRequest) XXX_DiscardUnknown

func (m *ListAssetsRequest) XXX_DiscardUnknown()

func (*ListAssetsRequest) XXX_Marshal

func (m *ListAssetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListAssetsRequest) XXX_Merge

func (dst *ListAssetsRequest) XXX_Merge(src proto.Message)

func (*ListAssetsRequest) XXX_Size

func (m *ListAssetsRequest) XXX_Size() int

func (*ListAssetsRequest) XXX_Unmarshal

func (m *ListAssetsRequest) XXX_Unmarshal(b []byte) error

type ListAssetsResponse

type ListAssetsResponse struct {
	Assets               []*Asset `protobuf:"bytes,1,rep,name=assets" json:"assets,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListAssetsResponse) Descriptor

func (*ListAssetsResponse) Descriptor() ([]byte, []int)

func (*ListAssetsResponse) GetAssets

func (m *ListAssetsResponse) GetAssets() []*Asset

func (*ListAssetsResponse) ProtoMessage

func (*ListAssetsResponse) ProtoMessage()

func (*ListAssetsResponse) Reset

func (m *ListAssetsResponse) Reset()

func (*ListAssetsResponse) String

func (m *ListAssetsResponse) String() string

func (*ListAssetsResponse) XXX_DiscardUnknown

func (m *ListAssetsResponse) XXX_DiscardUnknown()

func (*ListAssetsResponse) XXX_Marshal

func (m *ListAssetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListAssetsResponse) XXX_Merge

func (dst *ListAssetsResponse) XXX_Merge(src proto.Message)

func (*ListAssetsResponse) XXX_Size

func (m *ListAssetsResponse) XXX_Size() int

func (*ListAssetsResponse) XXX_Unmarshal

func (m *ListAssetsResponse) XXX_Unmarshal(b []byte) error

type ListTransactionsRequest

type ListTransactionsRequest struct {
	Address              string   `protobuf:"bytes,1,opt,name=address" json:"address,omitempty"`
	AssetID              string   `protobuf:"bytes,2,opt,name=assetID" json:"assetID,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListTransactionsRequest) Descriptor

func (*ListTransactionsRequest) Descriptor() ([]byte, []int)

func (*ListTransactionsRequest) GetAddress

func (m *ListTransactionsRequest) GetAddress() string

func (*ListTransactionsRequest) GetAssetID

func (m *ListTransactionsRequest) GetAssetID() string

func (*ListTransactionsRequest) ProtoMessage

func (*ListTransactionsRequest) ProtoMessage()

func (*ListTransactionsRequest) Reset

func (m *ListTransactionsRequest) Reset()

func (*ListTransactionsRequest) String

func (m *ListTransactionsRequest) String() string

func (*ListTransactionsRequest) XXX_DiscardUnknown

func (m *ListTransactionsRequest) XXX_DiscardUnknown()

func (*ListTransactionsRequest) XXX_Marshal

func (m *ListTransactionsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListTransactionsRequest) XXX_Merge

func (dst *ListTransactionsRequest) XXX_Merge(src proto.Message)

func (*ListTransactionsRequest) XXX_Size

func (m *ListTransactionsRequest) XXX_Size() int

func (*ListTransactionsRequest) XXX_Unmarshal

func (m *ListTransactionsRequest) XXX_Unmarshal(b []byte) error

type ListTransactionsResponse

type ListTransactionsResponse struct {
	Transactions         []*TX    `protobuf:"bytes,1,rep,name=transactions" json:"transactions,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListTransactionsResponse) Descriptor

func (*ListTransactionsResponse) Descriptor() ([]byte, []int)

func (*ListTransactionsResponse) GetTransactions

func (m *ListTransactionsResponse) GetTransactions() []*TX

func (*ListTransactionsResponse) ProtoMessage

func (*ListTransactionsResponse) ProtoMessage()

func (*ListTransactionsResponse) Reset

func (m *ListTransactionsResponse) Reset()

func (*ListTransactionsResponse) String

func (m *ListTransactionsResponse) String() string

func (*ListTransactionsResponse) XXX_DiscardUnknown

func (m *ListTransactionsResponse) XXX_DiscardUnknown()

func (*ListTransactionsResponse) XXX_Marshal

func (m *ListTransactionsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListTransactionsResponse) XXX_Merge

func (dst *ListTransactionsResponse) XXX_Merge(src proto.Message)

func (*ListTransactionsResponse) XXX_Size

func (m *ListTransactionsResponse) XXX_Size() int

func (*ListTransactionsResponse) XXX_Unmarshal

func (m *ListTransactionsResponse) XXX_Unmarshal(b []byte) error

type NonParamsRequest

type NonParamsRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*NonParamsRequest) Descriptor

func (*NonParamsRequest) Descriptor() ([]byte, []int)

func (*NonParamsRequest) ProtoMessage

func (*NonParamsRequest) ProtoMessage()

func (*NonParamsRequest) Reset

func (m *NonParamsRequest) Reset()

func (*NonParamsRequest) String

func (m *NonParamsRequest) String() string

func (*NonParamsRequest) XXX_DiscardUnknown

func (m *NonParamsRequest) XXX_DiscardUnknown()

func (*NonParamsRequest) XXX_Marshal

func (m *NonParamsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*NonParamsRequest) XXX_Merge

func (dst *NonParamsRequest) XXX_Merge(src proto.Message)

func (*NonParamsRequest) XXX_Size

func (m *NonParamsRequest) XXX_Size() int

func (*NonParamsRequest) XXX_Unmarshal

func (m *NonParamsRequest) XXX_Unmarshal(b []byte) error

type Output

type Output struct {
	Type                 string   `protobuf:"bytes,1,opt,name=type" json:"type,omitempty"`
	AssetID              string   `protobuf:"bytes,2,opt,name=assetID" json:"assetID,omitempty"`
	Amount               uint64   `protobuf:"varint,3,opt,name=amount" json:"amount,omitempty"`
	Address              string   `protobuf:"bytes,4,opt,name=address" json:"address,omitempty"`
	OutputID             string   `protobuf:"bytes,5,opt,name=OutputID" json:"OutputID,omitempty"`
	Position             int32    `protobuf:"varint,6,opt,name=position" json:"position,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Output) Descriptor

func (*Output) Descriptor() ([]byte, []int)

func (*Output) GetAddress

func (m *Output) GetAddress() string

func (*Output) GetAmount

func (m *Output) GetAmount() uint64

func (*Output) GetAssetID

func (m *Output) GetAssetID() string

func (*Output) GetOutputID

func (m *Output) GetOutputID() string

func (*Output) GetPosition

func (m *Output) GetPosition() int32

func (*Output) GetType

func (m *Output) GetType() string

func (*Output) ProtoMessage

func (*Output) ProtoMessage()

func (*Output) Reset

func (m *Output) Reset()

func (*Output) String

func (m *Output) String() string

func (*Output) XXX_DiscardUnknown

func (m *Output) XXX_DiscardUnknown()

func (*Output) XXX_Marshal

func (m *Output) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Output) XXX_Merge

func (dst *Output) XXX_Merge(src proto.Message)

func (*Output) XXX_Size

func (m *Output) XXX_Size() int

func (*Output) XXX_Unmarshal

func (m *Output) XXX_Unmarshal(b []byte) error

type SubmitTransactionRequest

type SubmitTransactionRequest struct {
	RawTransaction       string   `protobuf:"bytes,1,opt,name=rawTransaction" json:"rawTransaction,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

submit tx

func (*SubmitTransactionRequest) Descriptor

func (*SubmitTransactionRequest) Descriptor() ([]byte, []int)

func (*SubmitTransactionRequest) GetRawTransaction

func (m *SubmitTransactionRequest) GetRawTransaction() string

func (*SubmitTransactionRequest) ProtoMessage

func (*SubmitTransactionRequest) ProtoMessage()

func (*SubmitTransactionRequest) Reset

func (m *SubmitTransactionRequest) Reset()

func (*SubmitTransactionRequest) String

func (m *SubmitTransactionRequest) String() string

func (*SubmitTransactionRequest) XXX_DiscardUnknown

func (m *SubmitTransactionRequest) XXX_DiscardUnknown()

func (*SubmitTransactionRequest) XXX_Marshal

func (m *SubmitTransactionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*SubmitTransactionRequest) XXX_Merge

func (dst *SubmitTransactionRequest) XXX_Merge(src proto.Message)

func (*SubmitTransactionRequest) XXX_Size

func (m *SubmitTransactionRequest) XXX_Size() int

func (*SubmitTransactionRequest) XXX_Unmarshal

func (m *SubmitTransactionRequest) XXX_Unmarshal(b []byte) error

type SubmitTransactionResponse

type SubmitTransactionResponse struct {
	TxID                 string   `protobuf:"bytes,1,opt,name=txID" json:"txID,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*SubmitTransactionResponse) Descriptor

func (*SubmitTransactionResponse) Descriptor() ([]byte, []int)

func (*SubmitTransactionResponse) GetTxID

func (m *SubmitTransactionResponse) GetTxID() string

func (*SubmitTransactionResponse) ProtoMessage

func (*SubmitTransactionResponse) ProtoMessage()

func (*SubmitTransactionResponse) Reset

func (m *SubmitTransactionResponse) Reset()

func (*SubmitTransactionResponse) String

func (m *SubmitTransactionResponse) String() string

func (*SubmitTransactionResponse) XXX_DiscardUnknown

func (m *SubmitTransactionResponse) XXX_DiscardUnknown()

func (*SubmitTransactionResponse) XXX_Marshal

func (m *SubmitTransactionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*SubmitTransactionResponse) XXX_Merge

func (dst *SubmitTransactionResponse) XXX_Merge(src proto.Message)

func (*SubmitTransactionResponse) XXX_Size

func (m *SubmitTransactionResponse) XXX_Size() int

func (*SubmitTransactionResponse) XXX_Unmarshal

func (m *SubmitTransactionResponse) XXX_Unmarshal(b []byte) error

type TX

type TX struct {
	ID                     string    `protobuf:"bytes,1,opt,name=ID" json:"ID,omitempty"`
	Timestamp              uint64    `protobuf:"varint,2,opt,name=timestamp" json:"timestamp,omitempty"`
	BlockID                string    `protobuf:"bytes,3,opt,name=blockID" json:"blockID,omitempty"`
	BlockHeight            uint64    `protobuf:"varint,4,opt,name=blockHeight" json:"blockHeight,omitempty"`
	Position               uint32    `protobuf:"varint,5,opt,name=position" json:"position,omitempty"`
	BlockTransactionsCount uint32    `protobuf:"varint,6,opt,name=blockTransactionsCount" json:"blockTransactionsCount,omitempty"`
	Confirmation           uint64    `protobuf:"varint,7,opt,name=confirmation" json:"confirmation,omitempty"`
	StatusFail             bool      `protobuf:"varint,8,opt,name=statusFail" json:"statusFail,omitempty"`
	Inputs                 []*Input  `protobuf:"bytes,9,rep,name=inputs" json:"inputs,omitempty"`
	Outputs                []*Output `protobuf:"bytes,10,rep,name=outputs" json:"outputs,omitempty"`
	Op                     string    `protobuf:"bytes,11,opt,name=op" json:"op,omitempty"`
	Fee                    uint64    `protobuf:"varint,12,opt,name=fee" json:"fee,omitempty"`
	XXX_NoUnkeyedLiteral   struct{}  `json:"-"`
	XXX_unrecognized       []byte    `json:"-"`
	XXX_sizecache          int32     `json:"-"`
}

func (*TX) Descriptor

func (*TX) Descriptor() ([]byte, []int)

func (*TX) GetBlockHeight

func (m *TX) GetBlockHeight() uint64

func (*TX) GetBlockID

func (m *TX) GetBlockID() string

func (*TX) GetBlockTransactionsCount

func (m *TX) GetBlockTransactionsCount() uint32

func (*TX) GetConfirmation

func (m *TX) GetConfirmation() uint64

func (*TX) GetFee

func (m *TX) GetFee() uint64

func (*TX) GetID

func (m *TX) GetID() string

func (*TX) GetInputs

func (m *TX) GetInputs() []*Input

func (*TX) GetOp

func (m *TX) GetOp() string

func (*TX) GetOutputs

func (m *TX) GetOutputs() []*Output

func (*TX) GetPosition

func (m *TX) GetPosition() uint32

func (*TX) GetStatusFail

func (m *TX) GetStatusFail() bool

func (*TX) GetTimestamp

func (m *TX) GetTimestamp() uint64

func (*TX) ProtoMessage

func (*TX) ProtoMessage()

func (*TX) Reset

func (m *TX) Reset()

func (*TX) String

func (m *TX) String() string

func (*TX) XXX_DiscardUnknown

func (m *TX) XXX_DiscardUnknown()

func (*TX) XXX_Marshal

func (m *TX) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*TX) XXX_Merge

func (dst *TX) XXX_Merge(src proto.Message)

func (*TX) XXX_Size

func (m *TX) XXX_Size() int

func (*TX) XXX_Unmarshal

func (m *TX) XXX_Unmarshal(b []byte) error

Jump to